#version 3.7;

// povray ndi.pov +w1000 +h562 +a0.1 +am1 +r3
// 1 pov unit = 10ft

// -- Variables and setup
// 0=no rad, 1=load, 2=save
#declare WorkMode = no;
#declare Debug    = no;
#declare UseLight = yes;
#declare UseRad   = 1;
#declare UseGrid  = no;

#declare Render_Cloud = 1;

#default { finish { ambient 0 emission 0 diffuse 0.35 } }

global_settings {
	max_trace_level 80
	charset utf8
	adc_bailout 0.00001
	noise_generator 3
	assumed_gamma 1.0
	photons {count 5000}
	#if (UseRad)
		radiosity {
			#if (UseRad=2)
				count 32
				nearest_count 1
				error_bound .1
				gray_threshold 0
				recursion_limit 2
				pretrace_end 2/256
				normal on
			#else
				pretrace_start 1
				pretrace_end 1
				gray_threshold 1
				always_sample off
				normal on
		  #end
			}
	#end
	}

// -- Some Includes
#include "colors.inc"

#if (UseGrid)
	#include "grid.inc"
	object { grid scale 2 }
#end

#if (WorkMode)
	#declare CamPos = <0,24,-100>;
	#declare LookAt = <0,6,0>;
	#declare ZF = 2.5*z;
#else
	//#declare CamPos = <0,0.6,-30>;
	//#declare LookAt = <5,3,0>;
	//#declare ZF = 1*z;
	//#declare CamPos = <-10,1.4,-3>;
	//#declare LookAt = <22.1,4,33.15>;
	//#declare ZF = 1*z;
	
	//#declare CamPos = <0,250,0>;
	//#declare LookAt = <0,0,0>;
	#declare CamPos = <-10,0.6,-23>;
	#declare LookAt = <22.1,4,33.15>;
	#declare ZF = 1*z;
#end

// -- Camera & Lighting
camera {
	//orthographic
	perspective
	location CamPos
	look_at  LookAt
	#if (WorkMode)
		rotate x*10
		rotate y*0
	#else
		angle 45
	#end
	right  x*16/9
	direction ZF
	}

// -- The Sun Light
#declare AreaLight = yes;
#declare SpotLight = no;
#declare ParaLight = no;
#declare FadePower = 2;

#declare Intensity = function (LD,FD,FP) {pow(1+(LD/FD),FP)/2};

#declare LightPos = <0,0,-3000>;
#declare LightDist = vlength(LightPos-<0,0,-1500>);
#declare FadeDist = 3;

#if (Debug)
	#debug concat ("\nSun:\nFade Distance: ", str(FadeDist,2,4))
	#debug concat ("\nLight Distance: ", str(LightDist,5,4)," \n")
	#debug concat ("Light Intensity: ", str(Intensity (LightDist, FadeDist, FadePower),6,4), "\n\n")
#end

#if (UseLight)
#declare Sun_Light =
light_source {
	#if (Debug)
		#declare LightColor = White * 5;
	#else
		#declare LightColor = rgb 5;
	#end
 	0, LightColor *  Intensity (LightDist, FadeDist, FadePower)

	#if (Debug)
		looks_like {sphere {0,1 pigment {rgb <1,0.25,0.05>}} finish {emission <1,0.25,0.05> diffuse 0}}
	#end
	#if (ParaLight)
		parallel
	#end
	#if (SpotLight)
		spotlight
	#end
	#if (AreaLight)
		area_light x*0.03*LightDist, z*0.03*LightDist 5,5 adaptive 3 jitter orient circular
 	#end
	fade_distance FadeDist
 	fade_power FadePower
 	media_interaction on
 	media_attenuation on
 	translate LightPos
 	#if (ParaLight)
		point_at <0,0,-5>
	#end
	#if (SpotLight)	
		point_at <-15,6,7>
		radius 60
		falloff 70
		tightness 0
	#end
	media_attenuation on
	}
#end

#declare SkyDome =
sphere { 0, 1 hollow 
   pigment {
      gradient y
      poly_wave 0.25
      color_map {
         [0 srgb <210,220,230>/255]
         [1 srgb <100,160,200>/255]
      }
   }
   finish { diffuse 0 emission 1 }
   no_shadow 
}

object { SkyDome scale 5000 }
object { Sun_Light rotate x*30 rotate y*310} //310
plane { y,-0.01 hollow pigment {rgb 1 } }

#if (Render_Cloud)
   #local fnCloud = function { 
      pigment { 
         spherical 
         poly_wave 2
         color_map {
            [0.0 rgb 0 transmit 1]
            [0.3 rgb 0 transmit 1]
            [0.9 rgb 1]
            [1.0 rgb 1]
         }
         warp {
            turbulence 1
            omega 0.4
            octaves 3
            lambda 5
         }
      }
   }    
   sphere { 0, 1 hollow 
      pigment { rgb 1 transmit 1 }
      interior {
         media { 
            method 3 intervals 1 samples 8
            scattering { 3, color LightColor } 
            density { function { fnCloud(x,y,z).gray*1/25 } } 
         }
      }
      scale x*1.5 
      scale 20
      translate <39, 15, 50>*4 
   }
#end

#include "ndi_buildings.inc"
#include "logo.inc"
#include "ndi_centerpiece.inc"

// Scene Objects

//object { CenterPiece rotate y*90 translate <12.1,0.3,(12.5-1.5)> }

// the structure
union {
	object { FirstLevel }
	object { StairCase rotate y*90 translate <47.78,0,47.78> }
	object { SecondLevel translate <0,7,50> }
	object { ThirdLevel translate <0,12,50> }
	rotate y*0
	}

